@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2008 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007,2008,2011,2014,2015,2018 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -34,6 +34,7 @@
 /**   NAME       : arch_vhcub.h                            **/
 /**                                                        **/
 /**   AUTHOR     : Francois PELLEGRINI                     **/
+/**                Sebastien FOURESTIER (v6.0)             **/
 /**                                                        **/
 /**   FUNCTION   : These lines are the data declaration    **/
 /**                for the variable-sized hypercube        **/
@@ -45,6 +46,8 @@
 /**                                 to     04 nov 2003     **/
 /**                # Version 5.1  : from : 21 jan 2008     **/
 /**                                 to     21 jan 2008     **/
+/**                # Version 6.0  : from : 14 feb 2011     **/
+/**                                 to     28 may 2018     **/
 /**                                                        **/
 /************************************************************/
 
@@ -52,6 +55,9 @@
 **  The type and structure definitions.
 */
 
+#ifndef ARCH_VHCUB_H_STRUCT
+#define ARCH_VHCUB_H_STRUCT
+
 /*+ The variable-sized hypercube bipartitioning definitions. +*/
 
 typedef struct ArchVhcub_ {
@@ -63,17 +69,24 @@ typedef struct ArchVhcubDom_ {
   Anum                      termnum;              /*+ Terminal number +*/
 } ArchVhcubDom;
 
+#endif /* ARCH_VHCUB_H_STRUCT */
+
 /*
 **  The function prototypes.
 */
 
-#ifndef ARCH_VHCUB
-#define static
-#endif
+#ifndef ARCH_NOPROTO
+#ifndef ARCH_VHCUB_H_PROTO
+#define ARCH_VHCUB_H_PROTO
 
 #define archVhcubArchLoad           NULL
 #define archVhcubArchSave           NULL
 #define archVhcubArchFree           NULL
+
+#define archVhcubMatchInit          NULL
+#define archVhcubMatchExit          NULL
+#define archVhcubMatchMate          NULL
+
 ArchDomNum                  archVhcubDomNum     (const ArchVhcub * const, const ArchVhcubDom * const);
 int                         archVhcubDomTerm    (const ArchVhcub * const, ArchVhcubDom * restrict const, const ArchDomNum);
 Anum                        archVhcubDomSize    (const ArchVhcub * const, const ArchVhcubDom * const);
@@ -83,8 +96,10 @@ int                         archVhcubDomFrst    (const ArchVhcub * const, ArchVh
 int                         archVhcubDomLoad    (const ArchVhcub * const, ArchVhcubDom * const, FILE * const);
 int                         archVhcubDomSave    (const ArchVhcub * const, const ArchVhcubDom * const, FILE * const);
 int                         archVhcubDomBipart  (const ArchVhcub * const, const ArchVhcubDom * const, ArchVhcubDom * restrict const, ArchVhcubDom * restrict const);
+int                         archVhcubDomIncl    (const ArchVhcub * const, const ArchVhcubDom * const, const ArchVhcubDom * const);
 #ifdef SCOTCH_PTSCOTCH
 int                         archVhcubDomMpiType (const ArchVhcub * const, MPI_Datatype * const);
 #endif /* SCOTCH_PTSCOTCH */
 
-#undef static
+#endif /* ARCH_VHCUB_H_PROTO */
+#endif /* ARCH_NOPROTO       */
