@@ -1,4 +1,4 @@
-/* Copyright 2007-2011 ENSEIRB, INRIA & CNRS
+/* Copyright 2007-2011,2014 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -33,7 +33,7 @@
 /**                                                        **/
 /**   NAME       : bdgraph_bipart_st.c                     **/
 /**                                                        **/
-/**   AUTHOR     : Jun-Ho HER                              **/
+/**   AUTHOR     : Jun-Ho HER (v6.0)                       **/
 /**                Francois PELLEGRINI                     **/
 /**                                                        **/
 /**   FUNCTION   : This module contains the strategy and   **/
@@ -42,6 +42,8 @@
 /**                                                        **/
 /**   DATES      : # Version 5.1  : from : 10 sep 2007     **/
 /**                                 to   : 15 apr 2011     **/
+/**                # Version 6.0  : from : 11 sep 2011     **/
+/**                                 to   : 28 sep 2014     **/
 /**                                                        **/
 /************************************************************/
 
@@ -94,7 +96,7 @@ static union {
 static union {
   BdgraphBipartMlParam      param;
   StratNodeMethodData       padding;
-} bdgraphbipartstdefaultml = { { 5, 1000, 100, 0, 0.8L, &stratdummy, &stratdummy, &stratdummy} };
+} bdgraphbipartstdefaultml = { { 5, 1000, 2, 10000, 0.8L, &stratdummy, &stratdummy, &stratdummy} };
 
 static union {
   BdgraphBipartSqParam      param;
@@ -167,6 +169,14 @@ static StratParamTab        bdgraphbipartstparatab[] = { /* Method parameter lis
                                 (byte *) &bdgraphbipartstdefaultml.param,
                                 (byte *) &bdgraphbipartstdefaultml.param.coarnbr,
                                 NULL },
+                              { BDGRAPHBIPARTSTMETHML,  STRATPARAMINT,    "dvert",
+                                (byte *) &bdgraphbipartstdefaultml.param,
+                                (byte *) &bdgraphbipartstdefaultml.param.foldmax,
+                                NULL },
+                              { BDGRAPHBIPARTSTMETHML,  STRATPARAMCASE,   "fold",
+                                (byte *) &bdgraphbipartstdefaultml.param,
+                                (byte *) &bdgraphbipartstdefaultml.param.foldval,
+                                (void *) "nfd" },
                               { BDGRAPHBIPARTSTMETHML,  STRATPARAMDOUBLE, "rat",
                                 (byte *) &bdgraphbipartstdefaultml.param,
                                 (byte *) &bdgraphbipartstdefaultml.param.coarrat,
@@ -179,13 +189,17 @@ static StratParamTab        bdgraphbipartstparatab[] = { /* Method parameter lis
                                 NULL, NULL, NULL } };
 
 static StratParamTab        bdgraphbipartstcondtab[] = { /* Active graph condition parameter table */
-                              { STRATNODECOND,       STRATPARAMINT,    "load",
+                              { STRATNODECOND,       STRATPARAMDOUBLE, "bal",
                                 (byte *) &bdgraphdummy,
-                                (byte *) &bdgraphdummy.s.veloglbsum,
+                                (byte *) &bdgraphdummy.bbalglbval,
                                 NULL },
-                              { STRATNODECOND,       STRATPARAMINT,    "load0",
+                              { STRATNODECOND,       STRATPARAMINT,    "edge",
                                 (byte *) &bdgraphdummy,
-                                (byte *) &bdgraphdummy.compglbload0,
+                                (byte *) &bdgraphdummy.s.edgeglbnbr,
+                                NULL },
+                              { STRATNODECOND,       STRATPARAMINT,    "levl",
+                                (byte *) &bdgraphdummy,
+                                (byte *) &bdgraphdummy.levlnum,
                                 NULL },
                               { STRATNODECOND,       STRATPARAMINT,    "lmin0",
                                 (byte *) &bdgraphdummy,
@@ -195,17 +209,13 @@ static StratParamTab        bdgraphbipartstcondtab[] = { /* Active graph conditi
                                 (byte *) &bdgraphdummy,
                                 (byte *) &bdgraphdummy.compglbload0max,
                                 NULL },
-                              { STRATNODECOND,       STRATPARAMINT,    "edge",
+                              { STRATNODECOND,       STRATPARAMINT,    "load",
                                 (byte *) &bdgraphdummy,
-                                (byte *) &bdgraphdummy.s.edgeglbnbr,
+                                (byte *) &bdgraphdummy.s.veloglbsum,
                                 NULL },
-                              { STRATNODECOND,       STRATPARAMINT,    "vert",
+                              { STRATNODECOND,       STRATPARAMINT,    "load0",
                                 (byte *) &bdgraphdummy,
-                                (byte *) &bdgraphdummy.s.vertglbnbr,
-                                NULL },
-                              { STRATNODECOND,       STRATPARAMINT,    "levl",
-                                (byte *) &bdgraphdummy,
-                                (byte *) &bdgraphdummy.levlnum,
+                                (byte *) &bdgraphdummy.compglbload0,
                                 NULL },
                               { STRATNODECOND,       STRATPARAMINT,    "proc",
                                 (byte *) &bdgraphdummy,
@@ -215,6 +225,10 @@ static StratParamTab        bdgraphbipartstcondtab[] = { /* Active graph conditi
                                 (byte *) &bdgraphdummy,
                                 (byte *) &bdgraphdummy.s.proclocnum,
                                 NULL },
+                              { STRATNODECOND,       STRATPARAMINT,    "vert",
+                                (byte *) &bdgraphdummy,
+                                (byte *) &bdgraphdummy.s.vertglbnbr,
+                                NULL },
                               { STRATNODENBR,        STRATPARAMINT,    NULL,
                                 NULL, NULL, NULL } };
 
@@ -358,7 +372,7 @@ const Strat * restrict const  strat)              /*+ Bipartitioning strategy
 #endif /* SCOTCH_DEBUG_BDGRAPH1 */
 #ifdef SCOTCH_DEBUG_BDGRAPH2
       proccommold = grafptr->s.proccomm;          /* Create new communicator to isolate method communications */
-      MPI_Comm_dup (proccommold, &grafptr->s.proccomm); 
+      MPI_Comm_dup (proccommold, &grafptr->s.proccomm);
 #endif /* SCOTCH_DEBUG_BDGRAPH2 */
       o = (strat->tabl->methtab[strat->data.method.meth].func (grafptr, (void *) &strat->data.method.data));
 #ifdef SCOTCH_DEBUG_BDGRAPH2
