@@ -1,4 +1,4 @@
-/* Copyright 2007,2010 ENSEIRB, INRIA & CNRS
+/* Copyright 2007,2010,2018 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -33,7 +33,7 @@
 /**                                                        **/
 /**   NAME       : bdgraph_bipart_st.h                     **/
 /**                                                        **/
-/**   AUTHOR     : Jun-Ho HER                              **/
+/**   AUTHOR     : Jun-Ho HER (v6.0)                       **/
 /**                Francois PELLEGRINI                     **/
 /**                                                        **/
 /**   FUNCTION   : This module contains the data declara-  **/
@@ -44,6 +44,8 @@
 /**                                                        **/
 /**   DATES      : # Version 5.1  : from : 10 sep 2007     **/
 /**                                 to     16 jul 2010     **/
+/**                # Version 6.0  : from : 07 jun 2018     **/
+/**                                 to     07 jun 2018     **/
 /**                                                        **/
 /************************************************************/
 
@@ -73,10 +75,4 @@ extern StratTab             bdgraphbipartststratab;
 **  The function prototypes.
 */
 
-#ifndef BDGRAPH_BIPART_ST
-#define static
-#endif
-
 int                         bdgraphBipartSt   (Bdgraph * const, const Strat * const);
-
-#undef static
