@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2010,2011 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007,2010,2011,2014,2018 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -34,6 +34,7 @@
 /**   NAME       : bgraph.h                                **/
 /**                                                        **/
 /**   AUTHOR     : Francois PELLEGRINI                     **/
+/**                Sebastien FOURESTIER (v6.0)             **/
 /**                                                        **/
 /**   FUNCTION   : These lines are the data declaration    **/
 /**                for the job control routines of the     **/
@@ -61,6 +62,8 @@
 /**                                 to     30 nov 2006     **/
 /**                # Version 5.1  : from : 08 jan 2008     **/
 /**                                 to     18 mar 2011     **/
+/**                # Version 6.0  : from : 03 mar 2011     **/
+/**                                 to     05 apr 2018     **/
 /**                                                        **/
 /************************************************************/
 
@@ -72,15 +75,16 @@
 
 /*+ Graph option flags. +*/
 
-#define BGRAPHFREEFRON              (GRAPHBITSNOTUSED) /* Free frontier array           */
-#define BGRAPHFREEPART              (GRAPHBITSNOTUSED << 1) /* Free part array          */
-#define BGRAPHFREEVEEX              (GRAPHBITSNOTUSED << 2) /* Free external gain array */
+#define BGRAPHFREEFRON              (GRAPHBITSNOTUSED) /* Free frontier array               */
+#define BGRAPHFREEPART              (GRAPHBITSNOTUSED << 1) /* Free part array              */
+#define BGRAPHFREEVEEX              (GRAPHBITSNOTUSED << 2) /* Free external gain array     */
+#define BGRAPHHASANCHORS            (GRAPHBITSNOTUSED << 3) /* If graph has anchor vertices */
 
 /*+ The bipartition graph structure. +*/
 
 typedef struct Bgraph_ {
   Graph                     s;                    /*+ Source graph data                                  +*/
-  Gnum *                    veextax;              /*+ Vertex external gain array if moved to 1           +*/
+  Gnum *                    veextax;              /*+ Array of vertex external gain if moved to part 1   +*/
   GraphPart *               parttax;              /*+ Array of parts for every vertex                    +*/
   Gnum *                    frontab;              /*+ Array of frontier vertex numbers                   +*/
   Gnum                      fronnbr;              /*+ Number of frontier vertices                        +*/
@@ -94,10 +98,11 @@ typedef struct Bgraph_ {
   Gnum                      commloadextn0;        /*+ Communication load if all moved to part 0          +*/
   Gnum                      commgainextn0;        /*+ External gain if all swapped from part 0           +*/
   Gnum                      commgainextn;         /*+ External gain if all swapped                       +*/
-  Anum                      domdist;              /*+ Distance between subdomains                        +*/
-  Gnum                      domwght[2];           /*+ Weights of the two subdomains                      +*/
-  INT                       levlnum;              /*+ Coarsening level                                   +*/
   double                    bbalval;              /*+ Bipartitioning imbalance ratio (strategy variable) +*/
+  Anum                      domndist;             /*+ Distance between subdomains                        +*/
+  Gnum                      domnwght[2];          /*+ Weights of the two subdomains                      +*/
+  Gnum                      vfixload[2];          /*+ Vertex load biases of the two subdomains           +*/
+  INT                       levlnum;              /*+ Coarsening level                                   +*/
 } Bgraph;
 
 /*+ The save graph structure. +*/
@@ -115,17 +120,8 @@ typedef struct BgraphStore_ {
 **  The function prototypes.
 */
 
-#ifndef BGRAPH
-#define static
-#endif
-
-#ifdef MAPPING_H
-int                         bgraphInit          (Bgraph * const, const Graph * const, const Graph * const, const Mapping * const, const ArchDom[]);
-#endif /* MAPPING_H */
-void                        bgraphInit2         (Bgraph * const, const Anum, const Anum, const Anum);
-#ifdef MAPPING_H
-int                         bgraphInit3         (Bgraph * const, const Graph * const, const Mapping * const, const ArchDom[]);
-#endif /* MAPPING_H */
+int                         bgraphInit          (Bgraph * restrict const, const Graph * restrict const, const Arch * restrict const, const ArchDom * restrict const, const Gnum * restrict const);
+void                        bgraphInit2         (Bgraph * restrict const, const Anum, const Anum, const Anum, const Gnum, const Gnum);
 void                        bgraphExit          (Bgraph * restrict const);
 void                        bgraphSwal          (Bgraph * restrict const);
 void                        bgraphZero          (Bgraph * restrict const);
@@ -135,5 +131,3 @@ int                         bgraphStoreInit     (const Bgraph * const, BgraphSto
 void                        bgraphStoreExit     (BgraphStore * const);
 void                        bgraphStoreSave     (const Bgraph * const, BgraphStore * const);
 void                        bgraphStoreUpdt     (Bgraph * const, const BgraphStore * const);
-
-#undef static
