@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2011,2012 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2004,2007,2011,2012,2018 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -44,7 +44,7 @@
 /**                # Version 5.1  : from : 29 oct 2007     **/
 /**                                 to     28 mar 2011     **/
 /**                # Version 6.0  : from : 08 nov 2011     **/
-/**                                 to     20 nov 2012     **/
+/**                                 to     05 apr 2018     **/
 /**                                                        **/
 /************************************************************/
 
@@ -117,10 +117,4 @@ typedef struct BgraphBipartDfThread_ {
 **  The function prototypes.
 */
 
-#ifndef BGRAPH_BIPART_DF
-#define static
-#endif
-
 int                         bgraphBipartDf      (Bgraph * restrict const, const BgraphBipartDfParam * const);
-
-#undef static
