@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2009-2011 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007,2009-2012,2016,2017 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -34,6 +34,7 @@
 /**   NAME       : bgraph_bipart_st.c                      **/
 /**                                                        **/
 /**   AUTHOR     : Francois PELLEGRINI                     **/
+/**                Sebastien FOURESTIER (v6.0)             **/
 /**                                                        **/
 /**   FUNCTION   : This module contains the strategy and   **/
 /**                method tables for graph bipartitioning  **/
@@ -51,6 +52,8 @@
 /**                                 to     29 may 2007     **/
 /**                # Version 5.1  : from : 26 oct 2009     **/
 /**                                 to     15 apr 2011     **/
+/**                # Version 6.0  : from : 23 feb 2011     **/
+/**                                 to     02 jan 2017     **/
 /**                                                        **/
 /************************************************************/
 
@@ -62,11 +65,13 @@
 
 #include "module.h"
 #include "common.h"
+#include "fibo.h"
 #include "gain.h"
 #include "parser.h"
 #include "graph.h"
-#include "graph_coarsen.h"
 #include "arch.h"
+#include "mapping.h"
+#include "graph_coarsen.h"
 #include "bgraph.h"
 #include "bgraph_bipart_bd.h"
 #include "bgraph_bipart_df.h"
@@ -92,12 +97,12 @@ static union {
 static union {
   BgraphBipartDfParam       param;
   StratNodeMethodData       padding;
-} bgraphbipartstdefaultdf = { { 40, 1.0, 0.0, BGRAPHBIPARTDFTYPEBAL } };
+} bgraphbipartstdefaultdf = { { 40, BGRAPHBIPARTDFTYPEBAL } };
 
 static union {                                /* Default parameters for bipartitioning methods */
   BgraphBipartFmParam       param;            /* Parameter zone                                */
   StratNodeMethodData       padding;          /* To avoid reading out of structure             */
-} bgraphbipartstdefaultfm = { { 80, ~0, 0.01L } };
+} bgraphbipartstdefaultfm = { { 80, ~0, 0.01L, BGRAPHBIPARTFMTYPEBOUNDARY } };
 
 static union {
   BgraphBipartGgParam       param;
@@ -112,7 +117,7 @@ static union {
 static union {
   BgraphBipartMlParam       param;
   StratNodeMethodData       padding;
-} bgraphbipartstdefaultml = { { 100, 0.8L, GRAPHCOARHEM, &stratdummy, &stratdummy } };
+} bgraphbipartstdefaultml = { { 100, 0.8L, &stratdummy, &stratdummy } };
 
 static StratMethodTab       bgraphbipartstmethtab[] = { /* Bipartitioning methods array */
                               { BGRAPHBIPARTSTMETHBD, "b",  bgraphBipartBd, &bgraphbipartstdefaultbd },
@@ -142,14 +147,6 @@ static StratParamTab        bgraphbipartstparatab[] = { /* Method parameter list
                                 (byte *) &bgraphbipartstdefaultdf.param,
                                 (byte *) &bgraphbipartstdefaultdf.param.passnbr,
                                 NULL },
-                              { BGRAPHBIPARTSTMETHDF,  STRATPARAMDOUBLE, "dif",
-                                (byte *) &bgraphbipartstdefaultdf.param,
-                                (byte *) &bgraphbipartstdefaultdf.param.cdifval,
-                                NULL },
-                              { BGRAPHBIPARTSTMETHDF,  STRATPARAMDOUBLE, "rem",
-                                (byte *) &bgraphbipartstdefaultdf.param,
-                                (byte *) &bgraphbipartstdefaultdf.param.cremval,
-                                NULL },
                               { BGRAPHBIPARTSTMETHDF,  STRATPARAMCASE,   "type",
                                 (byte *) &bgraphbipartstdefaultdf.param,
                                 (byte *) &bgraphbipartstdefaultdf.param.typeval,
@@ -166,10 +163,18 @@ static StratParamTab        bgraphbipartstparatab[] = { /* Method parameter list
                                 (byte *) &bgraphbipartstdefaultfm.param,
                                 (byte *) &bgraphbipartstdefaultfm.param.deltval,
                                 NULL },
+                              { BGRAPHBIPARTSTMETHFM,  STRATPARAMCASE,   "type",
+                                (byte *) &bgraphbipartstdefaultfm.param,
+                                (byte *) &bgraphbipartstdefaultfm.param.typeval,
+                                (void *) "ab" },
                               { BGRAPHBIPARTSTMETHGG,  STRATPARAMINT,    "pass",
                                 (byte *) &bgraphbipartstdefaultgg.param,
                                 (byte *) &bgraphbipartstdefaultgg.param.passnbr,
                                 NULL },
+                              { BGRAPHBIPARTSTMETHGP,  STRATPARAMINT,    "pass",
+                                (byte *) &bgraphbipartstdefaultgp.param,
+                                (byte *) &bgraphbipartstdefaultgp.param.passnbr,
+                                NULL },
                               { BGRAPHBIPARTSTMETHML,  STRATPARAMSTRAT,  "asc",
                                 (byte *) &bgraphbipartstdefaultml.param,
                                 (byte *) &bgraphbipartstdefaultml.param.stratasc,
@@ -178,10 +183,6 @@ static StratParamTab        bgraphbipartstparatab[] = { /* Method parameter list
                                 (byte *) &bgraphbipartstdefaultml.param,
                                 (byte *) &bgraphbipartstdefaultml.param.stratlow,
                                 (void *) &bgraphbipartststratab },
-                              { BGRAPHBIPARTSTMETHML,  STRATPARAMCASE,   "type",
-                                (byte *) &bgraphbipartstdefaultml.param,
-                                (byte *) &bgraphbipartstdefaultml.param.coartype,
-                                (void *) "hscd" },
                               { BGRAPHBIPARTSTMETHML,  STRATPARAMINT,    "vert",
                                 (byte *) &bgraphbipartstdefaultml.param,
                                 (byte *) &bgraphbipartstdefaultml.param.coarnbr,
@@ -194,13 +195,17 @@ static StratParamTab        bgraphbipartstparatab[] = { /* Method parameter list
                                 NULL, NULL, NULL } };
 
 static StratParamTab        bgraphbipartstcondtab[] = { /* Active graph condition parameter table */
-                              { STRATNODECOND,       STRATPARAMINT,    "load",
+                              { STRATNODECOND,       STRATPARAMDOUBLE, "bal",
                                 (byte *) &bgraphdummy,
-                                (byte *) &bgraphdummy.s.velosum,
+                                (byte *) &bgraphdummy.bbalval,
                                 NULL },
-                              { STRATNODECOND,       STRATPARAMINT,    "load0",
+                              { STRATNODECOND,       STRATPARAMINT,    "edge",
                                 (byte *) &bgraphdummy,
-                                (byte *) &bgraphdummy.compload0,
+                                (byte *) &bgraphdummy.s.edgenbr,
+                                NULL },
+                              { STRATNODECOND,       STRATPARAMINT,    "levl",
+                                (byte *) &bgraphdummy,
+                                (byte *) &bgraphdummy.levlnum,
                                 NULL },
                               { STRATNODECOND,       STRATPARAMINT,    "lmin0",
                                 (byte *) &bgraphdummy,
@@ -210,18 +215,18 @@ static StratParamTab        bgraphbipartstcondtab[] = { /* Active graph conditio
                                 (byte *) &bgraphdummy,
                                 (byte *) &bgraphdummy.compload0max,
                                 NULL },
-                              { STRATNODECOND,       STRATPARAMINT,    "edge",
+                              { STRATNODECOND,       STRATPARAMINT,    "load",
                                 (byte *) &bgraphdummy,
-                                (byte *) &bgraphdummy.s.edgenbr,
+                                (byte *) &bgraphdummy.s.velosum,
+                                NULL },
+                              { STRATNODECOND,       STRATPARAMINT,    "load0",
+                                (byte *) &bgraphdummy,
+                                (byte *) &bgraphdummy.compload0,
                                 NULL },
                               { STRATNODECOND,       STRATPARAMINT,    "vert",
                                 (byte *) &bgraphdummy,
                                 (byte *) &bgraphdummy.s.vertnbr,
                                 NULL },
-                              { STRATNODECOND,       STRATPARAMINT,    "levl",
-                                (byte *) &bgraphdummy,
-                                (byte *) &bgraphdummy.levlnum,
-                                NULL },
                               { STRATNODENBR,        STRATPARAMINT,    NULL,
                                 NULL, NULL, NULL } };
 
@@ -323,7 +328,7 @@ const Strat * restrict const  strat)              /*+ Bipartitioning strategy
         compload0 = grafptr->compload0avg + savetab[0].compload0dlt;
         b0 = ((compload0 < grafptr->compload0min) ||
               (compload0 > grafptr->compload0max)) ? 1 : o;
-        compload0 = grafptr->compload0avg + savetab[1].compload0dlt;
+        compload0 = grafptr->compload0avg + grafptr->compload0dlt;
         b1 = ((compload0 < grafptr->compload0min) ||
               (compload0 > grafptr->compload0max)) ? 1 : o2;
 
