@@ -1,4 +1,4 @@
-/* Copyright 2007,2008,2010 ENSEIRB, INRIA & CNRS
+/* Copyright 2007,2008,2010,2012 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -44,6 +44,8 @@
 /**                                 to     17 jun 2008     **/
 /**                # Version 5.1  : from : 30 jul 2010     **/
 /**                                 to     30 jul 2010     **/
+/**                # Version 6.0  : from : 27 nov 2012     **/
+/**                                 to     27 nov 2012     **/
 /**                                                        **/
 /**   NOTES      : # The definitions of MPI_Gather and     **/
 /**                  MPI_Gatherv indicate that elements in **/
@@ -220,24 +222,22 @@ const int                     protnum)            /* -1 means allgather */
     edgetax = cgrfptr->edgetax - baseval;
     edlotax = (dgrfptr->edloloctax != NULL) ? (cgrfptr->edlotax - baseval) : NULL;
 
-    cgrfptr->flagval    = GRAPHFREEVERT | GRAPHVERTGROUP | GRAPHFREEEDGE | GRAPHEDGEGROUP; /* Other arrays are grouped, too */
-    cgrfptr->baseval    = baseval;
-    cgrfptr->vertnbr    = dgrfptr->vertglbnbr;
-    cgrfptr->vertnnd    = dgrfptr->vertglbnbr + baseval;
-    cgrfptr->verttax    = verttax;
-    cgrfptr->vendtax    = verttax + 1;            /* Compact edge array */
-    cgrfptr->velotax    = velotax;
-    cgrfptr->velosum    = dgrfptr->veloglbsum;
-    cgrfptr->vnumtax    = vnumtax;
-    cgrfptr->vlbltax    = vlbltax;
-    cgrfptr->edgenbr    = dgrfptr->edgeglbnbr;
-    cgrfptr->edgetax    = edgetax;
-    cgrfptr->edlotax    = edlotax;
-    cgrfptr->edlosum    = edlosum;
-    cgrfptr->degrmax    = dgrfptr->degrglbmax;
-    cgrfptr->proccomm   = MPI_COMM_NULL;          /* These fields exist only when compiled with SCOTCH_PTSCOTCH */
-    cgrfptr->procglbnbr = 1;                      /* Graph gathered on one single processor so no communicator  */
-    cgrfptr->proclocnum = 0;
+    cgrfptr->flagval = GRAPHFREEVERT | GRAPHVERTGROUP | GRAPHFREEEDGE | GRAPHEDGEGROUP; /* Other arrays are grouped, too */
+    cgrfptr->baseval = baseval;
+    cgrfptr->vertnbr = dgrfptr->vertglbnbr;
+    cgrfptr->vertnnd = dgrfptr->vertglbnbr + baseval;
+    cgrfptr->verttax = verttax;
+    cgrfptr->vendtax = verttax + 1;               /* Compact edge array */
+    cgrfptr->velotax = velotax;
+    cgrfptr->velosum = dgrfptr->veloglbsum;
+    cgrfptr->vnumtax = vnumtax;
+    cgrfptr->vlbltax = vlbltax;
+    cgrfptr->edgenbr = dgrfptr->edgeglbnbr;
+    cgrfptr->edgetax = edgetax;
+    cgrfptr->edlotax = edlotax;
+    cgrfptr->edlosum = edlosum;
+    cgrfptr->degrmax = dgrfptr->degrglbmax;
+    cgrfptr->procptr = NULL;                      /* This field exists only when compiled with SCOTCH_PTSCOTCH */
   }
 #ifdef SCOTCH_DEBUG_DGRAPH2                       /* Prevent Valgrind from yelling */
   else {                                          /* Process is not root           */
@@ -319,7 +319,7 @@ const int                     protnum)            /* -1 means allgather */
     if (dgraphGatherAll3 (dgrfptr->veloloctax + baseval, dgrfptr->vertlocnbr,
                           velotax,                /* Based array since procdsptab holds based values */
                           dgrfptr->proccnttab, dgrfptr->procdsptab, protnum, dgrfptr->proccomm) != MPI_SUCCESS) {
-      errorPrint ("dgraphGatherAll2: communication error (6)");
+      errorPrint ("dgraphGatherAll2: communication error (5)");
       return     (1);
     }
   }
@@ -327,7 +327,7 @@ const int                     protnum)            /* -1 means allgather */
     if (dgraphGatherAll3 (dgrfptr->vnumloctax + baseval, dgrfptr->vertlocnbr,
                           vnumtax,                /* Based array since procdsptab holds based values */
                           dgrfptr->proccnttab, dgrfptr->procdsptab, protnum, dgrfptr->proccomm) != MPI_SUCCESS) {
-      errorPrint ("dgraphGatherAll2: communication error (5)");
+      errorPrint ("dgraphGatherAll2: communication error (6)");
       return     (1);
     }
   }
