@@ -1,4 +1,4 @@
-/* Copyright 2004,2007-2009,2011 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007-2009,2011,2013-2016,2018 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -58,7 +58,7 @@
 /**                # Version 5.1  : from : 01 jan 2009     **/
 /**                                 to     01 jan 2009     **/
 /**                # Version 6.0  : from : 29 mar 2011     **/
-/**                                 to     29 mar 2011     **/
+/**                                 to     05 apr 2018     **/
 /**                                                        **/
 /**   NOTES      : # Several algorithms, such as the       **/
 /**                  active graph building routine of      **/
@@ -94,10 +94,6 @@
 ** array if the original graph does not have
 ** a vnumtab, or the proper subset of the
 ** original vnumtab else.
-** if rvnutax (reverse vnumtax) is not NULL
-** (and of size vertnbr), it will be filled
-** by new vertex numbers of ~0 if the vertex
-** is not in the induced graph.
 ** It returns:
 ** - 0   : on success.
 ** - !0  : on error.
@@ -106,88 +102,42 @@
 int
 graphInduceList (
 const Graph * restrict const    orggrafptr,
-const VertList * restrict const indlistptr,
-Graph * restrict const          indgrafptr,
-Gnum * restrict const           rvnutax)
+const Gnum                      indvnumnbr,
+const Gnum * restrict const     indvnumtab,
+Graph * restrict const          indgrafptr)
 {
-  Gnum * restrict     orgindxtax;                 /* Based access to vertex translation array       */
-  Gnum                indvertnbr;                 /* Number of vertices in induced graph            */
-  Gnum                indvertnum;                 /* Number of current vertex in induced graph      */
-  Gnum * restrict     indedgetab;                 /* Pointer to pre-allocated edge array            */
-  Gnum                indedgenbr;                 /* (Approximate) number of edges in induced graph */
+  Gnum * restrict       orgindxtax;               /* Based access to vertex translation array       */
+  Gnum                  indvertnnd;
+  Gnum                  indvertnum;               /* Number of current vertex in induced graph      */
+  const Gnum * restrict indvnumtax;
+  Gnum                  indedgenbr;               /* (Approximate) number of edges in induced graph */
 
-  memSet (indgrafptr, 0, sizeof (Graph));         /* Initialize graph fields */
-  indgrafptr->flagval = GRAPHFREETABS | GRAPHVERTGROUP | GRAPHEDGEGROUP;
-  indgrafptr->baseval = orggrafptr->baseval;
+  const Gnum * restrict const orgverttax = orggrafptr->verttax;
+  const Gnum * restrict const orgvendtax = orggrafptr->vendtax;
 
-  indvertnbr = indlistptr->vnumnbr;
-
-  if (orggrafptr->velotax != NULL) {
-    if (memAllocGroup ((void **) (void *)
-          &indgrafptr->verttax, (size_t) ((indvertnbr + 1) * sizeof (Gnum)),
-          &indgrafptr->vnumtax, (size_t) ( indvertnbr      * sizeof (Gnum)),
-          &indgrafptr->velotax, (size_t) ( indvertnbr      * sizeof (Gnum)), NULL) == NULL) {
-      errorPrint ("graphInduceList: out of memory (1)");
-      return     (1);                             /* Nothing to free because group allocation failed */
-    }
-    indgrafptr->velotax -= indgrafptr->baseval;
+  if (graphInduce2 (orggrafptr, indgrafptr, indvnumnbr) != 0) {
+    errorPrint ("graphInduceList: cannot create induced graph");
+    return     (1);
   }
-  else {
-    if (memAllocGroup ((void **) (void *)
-          &indgrafptr->verttax, (size_t) ((indvertnbr + 1) * sizeof (Gnum)),
-          &indgrafptr->vnumtax, (size_t) ( indvertnbr      * sizeof (Gnum)), NULL) == NULL) {
-      errorPrint ("graphInduceList: out of memory (2)");
-      return     (1);
-    }
-  }
-  indgrafptr->verttax -= indgrafptr->baseval;     /* Adjust base of arrays */
-  indgrafptr->vnumtax -= indgrafptr->baseval;
-  indgrafptr->vertnbr  = indvertnbr;
-  indgrafptr->vertnnd  = indvertnbr + indgrafptr->baseval;
-
-  indedgenbr = orggrafptr->edgenbr;               /* Choose best upper bound on number of edges (avoid multiply overflow) */
-  if ((orggrafptr->degrmax > 0) && (indvertnbr < (indedgenbr / orggrafptr->degrmax)))
-    indedgenbr = indvertnbr * orggrafptr->degrmax;
-  if (orggrafptr->edlotax != NULL)                /* If graph has edge weights */
-    indedgenbr *= 2;                              /* Account for edge weights  */
-
-  if (rvnutax == NULL) {
-    if (memAllocGroup ((void *)
-          &indedgetab, (size_t) (indedgenbr          * sizeof (Gnum)), /* Pre-allocate space for edgetab (and edlotab)          */
-          &orgindxtax, (size_t) (orggrafptr->vertnbr * sizeof (Gnum)), NULL) == NULL) { /* orgindxtab is at the end of the heap */
-      errorPrint ("graphInduceList: out of memory (3)");
-      graphExit  (indgrafptr);
-      return     (1);
-    }
-    orgindxtax -= orggrafptr->baseval;
-  }
-  else {
-    if ((indedgetab = memAlloc (indedgenbr * sizeof (Gnum))) == NULL) { /* Pre-allocate space for edgetab (and edlotab) */
-      errorPrint ("graphInduceList: out of memory (4)");
-      graphExit  (indgrafptr);
-      return     (1);
-    }
-    orgindxtax = rvnutax;
-  }
-
-/* TODO: Vertex list can be kept as it is the one of *graphOrderNd */
 
   memCpy (indgrafptr->vnumtax + indgrafptr->baseval, /* Copy vertex number array from list */
-          indlistptr->vnumtab, indvertnbr * sizeof (Gnum));
+          indvnumtab, indvnumnbr * sizeof (Gnum));
 
+  indvnumtax = indgrafptr->vnumtax;
+  orgindxtax = indgrafptr->edlotax;
   memSet (orgindxtax + orggrafptr->baseval, ~0, orggrafptr->vertnbr * sizeof (Gnum)); /* Preset index array */
 
-  for (indvertnum = indgrafptr->baseval, indedgenbr = 0; /* Fill index array */
-       indvertnum < indgrafptr->baseval + indvertnbr; indvertnum ++) {
+  for (indvertnum = indgrafptr->baseval, indvertnnd = indvertnum + indvnumnbr, indedgenbr = 0; /* Fill index array */
+       indvertnum < indvertnnd; indvertnum ++) {
     Gnum                orgvertnum;
 
-    orgvertnum = indgrafptr->vnumtax[indvertnum];
+    orgvertnum = indvnumtax[indvertnum];
 
     orgindxtax[orgvertnum] = indvertnum;          /* Mark selected vertices */
-    indedgenbr += orggrafptr->vendtax[orgvertnum] - orggrafptr->verttax[orgvertnum];
+    indedgenbr += orgvendtax[orgvertnum] - orgverttax[orgvertnum];
   }
 
-  return (graphInduce2 (orggrafptr, indgrafptr, indvertnbr, indedgenbr, indedgetab, orgindxtax));
+  return (graphInduce3 (orggrafptr, indgrafptr, indvnumnbr, indedgenbr));
 }
 
 /* This routine builds the graph induced
@@ -197,10 +147,6 @@ Gnum * restrict const           rvnutax)
 ** selected vertices if the original graph
 ** does not have a vnumtab, or the proper
 ** subset of the original vnumtab else.
-** if rvnutax (reverse vnumtax) is not NULL
-** (and of size vertnbr), it will be filled
-** by new vertex numbers of ~0 if the vertex
-** is not in the induced graph.
 ** It returns:
 ** - 0   : on success.
 ** - !0  : on error.
@@ -210,89 +156,110 @@ int
 graphInducePart (
 const Graph * restrict const  orggrafptr,         /* Pointer to original graph             */
 const GraphPart * const       orgparttax,         /* Based array of vertex partition flags */
-const Gnum                    indvertnbr,         /* Number of vertices in selected part   */
+const Gnum                    indvnumnbr,         /* Number of vertices in selected part   */
 const GraphPart               indpartval,         /* Partition value of vertices to keep   */
-Graph * restrict const        indgrafptr,         /* Pointer to induced subgraph           */
-Gnum * restrict const         rvnutax)
+Graph * restrict const        indgrafptr)         /* Pointer to induced subgraph           */
 {
-  Gnum * restrict             orgindxtax;         /* Based access to vertex translation array       */
-  Gnum                        indvertnum;         /* Number of current vertex in induced graph      */
-  Gnum * restrict             indedgetab;         /* Pointer to pre-allocated edge array            */
-  Gnum                        indedgenbr;         /* (Approximate) number of edges in induced graph */
-  Gnum                        orgvertnum;
+  Gnum * restrict     orgindxtax;                 /* Based access to vertex translation array       */
+  Gnum                orgvertnum;
+  Gnum                indvertnum;                 /* Number of current vertex in induced graph      */
+  Gnum * restrict     indvnumtax;
+  Gnum                indedgenbr;                 /* (Approximate) number of edges in induced graph */
 
-  memSet (indgrafptr, 0, sizeof (Graph));         /* Initialize graph fields */
-  indgrafptr->flagval = GRAPHFREETABS | GRAPHVERTGROUP | GRAPHEDGEGROUP;
-  indgrafptr->baseval = orggrafptr->baseval;
+  const Gnum * restrict const orgverttax = orggrafptr->verttax;
+  const Gnum * restrict const orgvendtax = orggrafptr->vendtax;
 
-  indedgenbr = ((orggrafptr->degrmax > 0) && (indvertnbr < (orggrafptr->edgenbr / orggrafptr->degrmax))) /* Choose best upper bound on number of edges (avoid multiply overflow) */
-               ? (indvertnbr * orggrafptr->degrmax) : orggrafptr->edgenbr;
-  if (orggrafptr->edlotax != NULL)                /* If graph has edge weights */
-    indedgenbr *= 2;                              /* Account for edge weights  */
-
-  if (orggrafptr->velotax != NULL) {
-    if (memAllocGroup ((void **) (void *)
-          &indgrafptr->verttax, (size_t) ((indvertnbr + 1) * sizeof (Gnum)),
-          &indgrafptr->vnumtax, (size_t) ( indvertnbr      * sizeof (Gnum)),
-          &indgrafptr->velotax, (size_t) ( indvertnbr      * sizeof (Gnum)), NULL) == NULL) {
-      errorPrint ("graphInducePart: out of memory (1)");
-      return     (1);                             /* Nothing to free because group allocation failed */
-    }
-    indgrafptr->velotax -= indgrafptr->baseval;
-  }
-  else {
-    if (memAllocGroup ((void **) (void *)
-          &indgrafptr->verttax, (size_t) ((indvertnbr + 1) * sizeof (Gnum)),
-          &indgrafptr->vnumtax, (size_t) ( indvertnbr      * sizeof (Gnum)), NULL) == NULL) {
-      errorPrint ("graphInducePart: out of memory (2)");
-      return     (1);
-    }
-  }
-  indgrafptr->verttax -= indgrafptr->baseval;     /* Adjust base of arrays */
-  indgrafptr->vnumtax -= indgrafptr->baseval;
-  indgrafptr->vertnbr  = indvertnbr;
-  indgrafptr->vertnnd  = indvertnbr + indgrafptr->baseval;
-
-  if (rvnutax == NULL) {
-    if (memAllocGroup ((void *)
-          &indedgetab, (size_t) (indedgenbr          * sizeof (Gnum)), /* Pre-allocate space for edgetab (and edlotab)          */
-          &orgindxtax, (size_t) (orggrafptr->vertnbr * sizeof (Gnum)), NULL) == NULL) { /* orgindxtab is at the end of the heap */
-      errorPrint ("graphInducePart: out of memory (3)");
-      graphExit  (indgrafptr);
-      return     (1);
-    }
-    orgindxtax -= orggrafptr->baseval;
-  }
-  else {
-    if ((indedgetab = memAlloc (indedgenbr * sizeof (Gnum))) == NULL) { /* Pre-allocate space for edgetab (and edlotab) */
-      errorPrint ("graphInduceList: out of memory (4)");
-      graphExit  (indgrafptr);
-      return     (1);
-    }
-    orgindxtax = rvnutax;
+  if (graphInduce2 (orggrafptr, indgrafptr, indvnumnbr) != 0) {
+    errorPrint ("graphInducePart: cannot create induced graph");
+    return     (1);
   }
 
-  for (indvertnum = indgrafptr->baseval, indedgenbr = 0, orgvertnum = orggrafptr->baseval; /* Fill index array */
+  orgindxtax = indgrafptr->edlotax;
+  indvnumtax = indgrafptr->vnumtax;
+  for (orgvertnum = indvertnum = orggrafptr->baseval, indedgenbr = 0; /* Fill index array */
        orgvertnum < orggrafptr->vertnnd; orgvertnum ++) {
     if (orgparttax[orgvertnum] == indpartval) {   /* If vertex should be kept */
       orgindxtax[orgvertnum] = indvertnum;        /* Mark selected vertex     */
-      indgrafptr->vnumtax[indvertnum] = orgvertnum;
-      indedgenbr += orggrafptr->vendtax[orgvertnum] - orggrafptr->verttax[orgvertnum];
+      indvnumtax[indvertnum] = orgvertnum;
+      indedgenbr += orgvendtax[orgvertnum] - orgverttax[orgvertnum];
       indvertnum ++;                              /* One more induced vertex created */
     }
     else
       orgindxtax[orgvertnum] = ~0;
   }
 #ifdef SCOTCH_DEBUG_GRAPH2
-  if ((indvertnum - indgrafptr->baseval) != indvertnbr) {
+  if ((indvertnum - indgrafptr->baseval) != indvnumnbr) {
     errorPrint ("graphInducePart: inconsistent data");
-    memFree    (indedgetab);
     graphExit  (indgrafptr);
     return     (1);
   }
 #endif /* SCOTCH_DEBUG_GRAPH2 */
 
-  return (graphInduce2 (orggrafptr, indgrafptr, indvertnbr, indedgenbr, indedgetab, orgindxtax));
+  return (graphInduce3 (orggrafptr, indgrafptr, indvnumnbr, indedgenbr));
+}
+
+/* This routine initializes the induced
+** graph structure.
+** It returns:
+** - 0   : on success.
+** - !0  : on error.
+*/
+
+static
+int
+graphInduce2 (
+const Graph * restrict const  orggrafptr,         /* Pointer to original graph           */
+Graph * restrict const        indgrafptr,         /* Pointer to induced graph            */
+const Gnum                    indvertnbr)         /* Number of vertices in induced graph */
+{
+  Gnum                  indedgenbr;               /* (Approximate) number of edges in induced graph */
+
+  const Gnum                baseval = orggrafptr->baseval; /* Fast accesses */
+
+  memSet (indgrafptr, 0, sizeof (Graph));         /* Initialize graph fields */
+  indgrafptr->flagval = GRAPHFREETABS | GRAPHVERTGROUP | GRAPHEDGEGROUP;
+  indgrafptr->baseval = baseval;
+
+  if (orggrafptr->velotax != NULL) {
+    if (memAllocGroup ((void **) (void *)
+                       &indgrafptr->verttax, (size_t) ((indvertnbr + 1) * sizeof (Gnum)),
+                       &indgrafptr->vnumtax, (size_t) ( indvertnbr      * sizeof (Gnum)),
+                       &indgrafptr->velotax, (size_t) ( indvertnbr      * sizeof (Gnum)), NULL) == NULL) {
+      errorPrint ("graphInduce2: out of memory (1)");
+      return     (1);                             /* Nothing to free because group allocation failed */
+    }
+    indgrafptr->velotax -= baseval;
+  }
+  else {
+    if (memAllocGroup ((void **) (void *)
+                       &indgrafptr->verttax, (size_t) ((indvertnbr + 1) * sizeof (Gnum)),
+                       &indgrafptr->vnumtax, (size_t) ( indvertnbr      * sizeof (Gnum)), NULL) == NULL) {
+      errorPrint ("graphInduce2: out of memory (2)");
+      return     (1);
+    }
+  }
+  indgrafptr->verttax -= baseval;                 /* Adjust base of arrays */
+  indgrafptr->vnumtax -= baseval;
+  indgrafptr->vertnbr  = indvertnbr;
+  indgrafptr->vertnnd  = indvertnbr + baseval;
+
+  indedgenbr = orggrafptr->edgenbr;               /* Choose best upper bound on number of edges (avoid multiply overflow) */
+  if ((orggrafptr->degrmax > 0) && (indvertnbr < (indedgenbr / orggrafptr->degrmax)))
+    indedgenbr = indvertnbr * orggrafptr->degrmax;
+  if (orggrafptr->edlotax != NULL)                /* If graph has edge weights */
+    indedgenbr *= 2;                              /* Account for edge weights  */
+
+  if (memAllocGroup ((void *)
+                     &indgrafptr->edgetax, (size_t) (indedgenbr          * sizeof (Gnum)), /* Pre-allocate space for edgetab (and edlotab)          */
+                     &indgrafptr->edlotax, (size_t) (orggrafptr->vertnbr * sizeof (Gnum)), NULL) == NULL) { /* orgindxtab is at the end of the heap */
+    errorPrint ("graphInduce2: out of memory (3)");
+    graphExit  (indgrafptr);
+    return     (1);
+  }
+  indgrafptr->edgetax -= baseval;                 /* TRICK: base edge array in case of premature freeing */
+  indgrafptr->edlotax -= baseval;                 /* TRICK: use edlotax as return slot for orgindxtax    */
+
+  return (0);
 }
 
 /* This routine finalizes the building
@@ -304,93 +271,106 @@ Gnum * restrict const         rvnutax)
 
 static
 int
-graphInduce2 (
+graphInduce3 (
 const Graph * restrict const  orggrafptr,         /* Pointer to original graph                          */
 Graph * restrict const        indgrafptr,         /* Pointer to induced graph                           */
 const Gnum                    indvertnbr,         /* Number of vertices in induced graph                */
-const Gnum                    indedgenbr,         /* (Upper bound of) number of edges in induced graph  */
-Gnum * restrict const         indedgetab,         /* Pointer to pre-allocated edge and edge load arrays */
-const Gnum * restrict const   orgindxtax)         /* Array of numbers of selected vertices              */
+const Gnum                    indedgenbr)         /* (Upper bound of) number of edges in induced graph  */
 {
-  Gnum                indvertnum;                 /* Current induced vertex number              */
-  Gnum                indvelosum;                 /* Overall induced vertex load                */
-  Gnum                indedlosum;                 /* Overall induced edge load                  */
-  Gnum                indedgenum;                 /* Number of current induced edge             */
-  Gnum                orgvertnum;                 /* Number of current vertex in original graph */
-  Gnum                orgedgenum;                 /* Number of current edge in original graph   */
+  Gnum                orgvertnum;
+  Gnum                orgedgenum;
+  Gnum                indvertnum;
+  Gnum                indvelosum;                 /* Overall induced vertex load    */
+  Gnum                indedlosum;                 /* Overall induced edge load      */
+  Gnum                indedgenum;                 /* Number of current induced edge */
+  Gnum * restrict     indedgetax;
+  Gnum * restrict     indedlotax;
 
-  if (orggrafptr->edlotax != NULL) {
-    memOffset ((void *) indedgetab,
-               &indgrafptr->edgetax, (size_t) (indedgenbr * sizeof (Gnum)),
-               &indgrafptr->edlotax, (size_t) (indedgenbr * sizeof (Gnum)), NULL);
-    indgrafptr->edgetax -= indgrafptr->baseval;
-    indgrafptr->edlotax -= indgrafptr->baseval;
+  const Gnum * restrict const orgverttax = orggrafptr->verttax;
+  const Gnum * restrict const orgvendtax = orggrafptr->vendtax;
+  const Gnum * restrict const orgvelotax = orggrafptr->velotax;
+  const Gnum * restrict const orgvnumtax = orggrafptr->vnumtax;
+  const Gnum * restrict const orgedgetax = orggrafptr->edgetax;
+  const Gnum * restrict const orgedlotax = orggrafptr->edlotax;
+  const Gnum * restrict const orgindxtax = indgrafptr->edlotax; /* TRICK: get orgindxtax from edlotax */
+  Gnum * restrict const       indverttax = indgrafptr->verttax;
+  Gnum * restrict const       indvelotax = indgrafptr->velotax;
+  Gnum * restrict const       indvnumtax = indgrafptr->vnumtax;
+
+  if (orgedlotax != NULL) {
+    memOffset ((void *) indgrafptr->edgetax,      /* TRICK: compute based offsets from based array */
+               &indedgetax, (size_t) (indedgenbr * sizeof (Gnum)),
+               &indedlotax, (size_t) (indedgenbr * sizeof (Gnum)), NULL);
+  }
+  else {
+    indedgetax = indgrafptr->edgetax;
+    indedlotax = NULL;
   }
-  else
-    indgrafptr->edgetax = indedgetab - indgrafptr->baseval;
 
-  indvelosum = (indgrafptr->velotax == NULL) ? indgrafptr->vertnbr : 0;
+  indvelosum = (indvelotax == NULL) ? indgrafptr->vertnbr : 0;
   indedlosum = 0;
   for (indvertnum = indedgenum = indgrafptr->baseval;
        indvertnum < indgrafptr->vertnnd; indvertnum ++) {
-    orgvertnum = indgrafptr->vnumtax[indvertnum];
-    indgrafptr->verttax[indvertnum] = indedgenum;
-    if (indgrafptr->velotax != NULL) {            /* If graph has vertex weights */
+    orgvertnum = indvnumtax[indvertnum];
+    indverttax[indvertnum] = indedgenum;
+    if (indvelotax != NULL) {                     /* If graph has vertex weights */
       indvelosum +=                               /* Accumulate vertex loads     */
-      indgrafptr->velotax[indvertnum] = orggrafptr->velotax[orgvertnum];
+      indvelotax[indvertnum] = orgvelotax[orgvertnum];
     }
 
-    if (indgrafptr->edlotax != NULL) {            /* If graph has edge weights */
-      for (orgedgenum = orggrafptr->verttax[orgvertnum];
-           orgedgenum < orggrafptr->vendtax[orgvertnum]; orgedgenum ++) {
-        if (orgindxtax[orggrafptr->edgetax[orgedgenum]] != ~0) { /* If edge should be kept */
-          indedlosum                     +=
-          indgrafptr->edlotax[indedgenum] = orggrafptr->edlotax[orgedgenum];
-          indgrafptr->edgetax[indedgenum] = orgindxtax[orggrafptr->edgetax[orgedgenum]];
+    if (indedlotax != NULL) {                     /* If graph has edge weights */
+      for (orgedgenum = orgverttax[orgvertnum];
+           orgedgenum < orgvendtax[orgvertnum]; orgedgenum ++) {
+        if (orgindxtax[orgedgetax[orgedgenum]] != ~0) { /* If edge should be kept */
+          indedlosum            +=
+          indedlotax[indedgenum] = orgedlotax[orgedgenum];
+          indedgetax[indedgenum] = orgindxtax[orgedgetax[orgedgenum]];
           indedgenum ++;
         }
       }
     }
     else {
-      for (orgedgenum = orggrafptr->verttax[orgvertnum];
-           orgedgenum < orggrafptr->vendtax[orgvertnum]; orgedgenum ++) {
-        if (orgindxtax[orggrafptr->edgetax[orgedgenum]] != ~0) { /* If edge should be kept */
-          indgrafptr->edgetax[indedgenum] = orgindxtax[orggrafptr->edgetax[orgedgenum]];
+      for (orgedgenum = orgverttax[orgvertnum];
+           orgedgenum < orgvendtax[orgvertnum]; orgedgenum ++) {
+        if (orgindxtax[orgedgetax[orgedgenum]] != ~0) { /* If edge should be kept */
+          indedgetax[indedgenum] = orgindxtax[orgedgetax[orgedgenum]];
           indedgenum ++;
         }
       }
     }
   }
-  indgrafptr->verttax[indvertnum] = indedgenum;   /* Mark end of edge array                      */
-  indgrafptr->vendtax  = indgrafptr->verttax + 1; /* Use compact representation of vertex arrays */
+  indverttax[indvertnum] = indedgenum;            /* Mark end of edge array */
+
+  indgrafptr->vendtax = indgrafptr->verttax + 1;  /* Use compact representation of vertex arrays */
   indgrafptr->vertnbr = indvertnum - indgrafptr->baseval;
   indgrafptr->vertnnd = indvertnum;
   indgrafptr->velosum = indvelosum;
   indgrafptr->edgenbr = indedgenum - indgrafptr->baseval; /* Set actual number of edges */
-  indgrafptr->edlosum = (indgrafptr->edlotax != NULL) ? indedlosum : indgrafptr->edgenbr;
-  indgrafptr->degrmax = orggrafptr->degrmax;      /* Induced maximum degree is likely to be the one of the original graph */
-
-  if (indgrafptr->edlotax != NULL) {              /* Re-allocate arrays and delete orgindxtab             */
-    size_t              indedlooftval;            /* Offset of edge load array with respect to edge array */
-
-    indedlooftval = indgrafptr->edlotax - indgrafptr->edgetax;
-    indgrafptr->edgetax  = memRealloc (indgrafptr->edgetax + indgrafptr->baseval, (indedlooftval + indgrafptr->edgenbr) * sizeof (Gnum));
-    indgrafptr->edgetax -= indgrafptr->baseval;
-    indgrafptr->edlotax  = indgrafptr->edgetax + indedlooftval; /* Use old index into old array as new index */
-  }
-  else {
-    indgrafptr->edgetax  = memRealloc (indgrafptr->edgetax + indgrafptr->baseval, indgrafptr->edgenbr * sizeof (Gnum));
-    indgrafptr->edgetax -= indgrafptr->baseval;
-  }
+  indgrafptr->edlosum = (indedlotax != NULL) ? indedlosum : indgrafptr->edgenbr;
+  indgrafptr->degrmax = orggrafptr->degrmax;      /* Induced maximum degree is likely to be that of the original graph */
 
   if (orggrafptr->vnumtax != NULL) {              /* Adjust vnumtax */
     for (indvertnum = indgrafptr->baseval; indvertnum < indgrafptr->vertnnd; indvertnum ++)
-      indgrafptr->vnumtax[indvertnum] = orggrafptr->vnumtax[indgrafptr->vnumtax[indvertnum]];
+      indvnumtax[indvertnum] = orgvnumtax[indvnumtax[indvertnum]];
+  }
+
+  if (indedlotax != NULL) {                       /* Re-allocate arrays and delete orgindxtab             */
+    size_t              indedlooftval;            /* Offset of edge load array with respect to edge array */
+
+    indedlooftval = indedlotax - indedgetax;
+    indgrafptr->edgetax = (Gnum *) memRealloc ((indgrafptr->edgetax + indgrafptr->baseval),
+                                               (indedlooftval + indgrafptr->edgenbr) * sizeof (Gnum)) - indgrafptr->baseval;
+    indgrafptr->edlotax = indgrafptr->edgetax + indedlooftval; /* Use old index into old array as new index */
+  }
+  else {
+    indgrafptr->edgetax = (Gnum *) memRealloc ((indgrafptr->edgetax + indgrafptr->baseval),
+                                               indgrafptr->edgenbr * sizeof (Gnum)) - indgrafptr->baseval;
+    indgrafptr->edlotax = NULL;                   /* Delete link to orgindxtax */
   }
 
 #ifdef SCOTCH_DEBUG_GRAPH2
   if (graphCheck (indgrafptr) != 0) {             /* Check graph consistency */
-    errorPrint ("graphInduce2: inconsistent graph data");
+    errorPrint ("graphInduce3: inconsistent graph data");
     graphExit  (indgrafptr);
     return     (1);
   }
