@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2010 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007,2010,2014,2018 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -47,6 +47,8 @@
 /**                                 to   : 01 jan 2003     **/
 /**                # Version 5.1  : from : 04 nov 2010     **/
 /**                                 to   : 04 nov 2010     **/
+/**                # Version 6.0  : from : 09 nov 2014     **/
+/**                                 to     07 jun 2018     **/
 /**                                                        **/
 /************************************************************/
 
@@ -88,12 +90,8 @@ typedef struct HgraphOrderCpMate_ {
 **  The function prototypes.
 */
 
-#ifndef HGRAPH_ORDER_CP
-#define static
-#endif
+#ifdef HGRAPH_ORDER_CP
+static Gnum                 hgraphOrderCpTree   (const Gnum * const, const Gnum * const, OrderCblk * const, const Gnum);
+#endif /* HGRAPH_ORDER_CP */
 
 int                         hgraphOrderCp       (const Hgraph * const, Order * const, const Gnum, OrderCblk * const, const HgraphOrderCpParam * const);
-
-static Gnum                 hgraphOrderCpTree   (const Gnum * const, const Gnum * const, OrderCblk * const, Gnum);
-
-#undef static
