@@ -1,4 +1,4 @@
-/* Copyright 2007,2009,2010,2012 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2007,2009,2010,2012,2018 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -44,7 +44,7 @@
 /**                # Version 5.1  : from : 26 mar 2009     **/
 /**                                 to     17 nov 2010     **/
 /**                # Version 6.0  : from : 27 nov 2012     **/
-/**                                 to     29 nov 2012     **/
+/**                                 to     25 apr 2018     **/
 /**                                                        **/
 /************************************************************/
 
@@ -102,17 +102,17 @@ MPI_Comm                    proccomm)             /* Communicator to be used for
 #ifdef SCOTCH_PTHREAD
   MPI_Query_thread (&thrdlvlval);
   if (thrdlvlval < MPI_THREAD_MULTIPLE) {
-    errorPrint ("SCOTCH_dgraphInit: Scotch compiled with SCOTCH_PTHREAD and program not launched with MPI_THREAD_MULTIPLE");
+    errorPrint (STRINGIFY (SCOTCH_dgraphInit) ": Scotch compiled with SCOTCH_PTHREAD and program not launched with MPI_THREAD_MULTIPLE");
     return     (1);
   }
 #endif /* SCOTCH_PTHREAD */
 
   if (sizeof (SCOTCH_Num) != sizeof (Gnum)) {
-    errorPrint ("SCOTCH_dgraphInit: internal error (1)");
+    errorPrint (STRINGIFY (SCOTCH_dgraphInit) ": internal error (1)");
     return     (1);
   }
   if (sizeof (SCOTCH_Dgraph) < sizeof (Dgraph)) {
-    errorPrint ("SCOTCH_dgraphInit: internal error (2)");
+    errorPrint (STRINGIFY (SCOTCH_dgraphInit) ": internal error (2)");
     return     (1);
   }
 
