@@ -1,4 +1,4 @@
-/* Copyright 2007,2012 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2007,2012,2018 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -43,7 +43,7 @@
 /**   DATES      : # Version 5.0  : from : 18 oct 2007     **/
 /**                                 to     18 oct 2007     **/
 /**                # Version 6.0  : from : 29 nov 2012     **/
-/**                                 to     29 nov 2012     **/
+/**                                 to     25 apr 2018     **/
 /**                                                        **/
 /************************************************************/
 
@@ -64,12 +64,12 @@
 /*                                    */
 /**************************************/
 
-FORTRAN (                                         \
-SCOTCHFDGRAPHORDERPERM, scotchfdgraphorderperm, ( \
-const SCOTCH_Dgraph * const     grafptr,          \
-const SCOTCH_Dordering * const  ordeptr,          \
-SCOTCH_Num * const              permloctab,       \
-int * const                     revaptr),         \
+SCOTCH_FORTRAN (                            \
+DGRAPHORDERPERM, dgraphorderperm, (         \
+const SCOTCH_Dgraph * const     grafptr,    \
+const SCOTCH_Dordering * const  ordeptr,    \
+SCOTCH_Num * const              permloctab, \
+int * const                     revaptr),   \
 (grafptr, ordeptr, permloctab, revaptr))
 {
   *revaptr = SCOTCH_dgraphOrderPerm (grafptr, ordeptr, permloctab);
