@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2008,2010 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007,2008,2010,2012,2018 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -47,6 +47,8 @@
 /**                                 to     31 may 2008     **/
 /**                # Version 5.1  : from : 27 mar 2010     **/
 /**                                 to     25 jul 2010     **/
+/**                # Version 6.0  : from : 08 jan 2012     **/
+/**                                 to     25 apr 2018     **/
 /**                                                        **/
 /************************************************************/
 
@@ -71,17 +73,17 @@
 **
 */
 
-FORTRAN (                                       \
-SCOTCHFGRAPHORDERINIT, scotchfgraphorderinit, ( \
-const SCOTCH_Graph * const  grafptr,            \
-SCOTCH_Ordering * const     ordeptr,            \
-SCOTCH_Num * const          permtab,            \
-SCOTCH_Num * const          peritab,            \
-SCOTCH_Num * const          cblkptr,            \
-SCOTCH_Num * const          rangtab,            \
-SCOTCH_Num * const          treetab,            \
-int * const                 revaptr),           \
-(grafptr, ordeptr, permtab, peritab,            \
+SCOTCH_FORTRAN (                      \
+GRAPHORDERINIT, graphorderinit, (     \
+const SCOTCH_Graph * const  grafptr,  \
+SCOTCH_Ordering * const     ordeptr,  \
+SCOTCH_Num * const          permtab,  \
+SCOTCH_Num * const          peritab,  \
+SCOTCH_Num * const          cblkptr,  \
+SCOTCH_Num * const          rangtab,  \
+SCOTCH_Num * const          treetab,  \
+int * const                 revaptr), \
+(grafptr, ordeptr, permtab, peritab,  \
  cblkptr, rangtab, treetab, revaptr))
 {
   *revaptr = SCOTCH_graphOrderInit (grafptr, ordeptr, permtab, peritab, cblkptr, rangtab, treetab);
@@ -91,10 +93,10 @@ int * const                 revaptr),           \
 **
 */
 
-FORTRAN (                                       \
-SCOTCHFGRAPHORDEREXIT, scotchfgraphorderexit, ( \
-const SCOTCH_Graph * const  grafptr,            \
-SCOTCH_Ordering * const     ordeptr),           \
+SCOTCH_FORTRAN (                      \
+GRAPHORDEREXIT, graphorderexit, (     \
+const SCOTCH_Graph * const  grafptr,  \
+SCOTCH_Ordering * const     ordeptr), \
 (grafptr, ordeptr))
 {
   SCOTCH_graphOrderExit (grafptr, ordeptr);
@@ -104,12 +106,12 @@ SCOTCH_Ordering * const     ordeptr),           \
 **
 */
 
-FORTRAN (                                       \
-SCOTCHFGRAPHORDERSAVE, scotchfgraphordersave, ( \
-const SCOTCH_Graph * const    grafptr,          \
-const SCOTCH_Ordering * const ordeptr,          \
-int * const                   fileptr,          \
-int * const                   revaptr),         \
+SCOTCH_FORTRAN (                        \
+GRAPHORDERSAVE, graphordersave, (       \
+const SCOTCH_Graph * const    grafptr,  \
+const SCOTCH_Ordering * const ordeptr,  \
+int * const                   fileptr,  \
+int * const                   revaptr), \
 (grafptr, ordeptr, fileptr, revaptr))
 {
   FILE *              stream;                     /* Stream to build from handle */
@@ -117,13 +119,12 @@ int * const                   revaptr),         \
   int                 o;
 
   if ((filenum = dup (*fileptr)) < 0) {           /* If cannot duplicate file descriptor */
-    errorPrint ("SCOTCHFGRAPHORDERSAVE: cannot duplicate handle");
-
+    errorPrint (STRINGIFY (SCOTCH_NAME_PUBLICFU (GRAPHORDERSAVE)) ": cannot duplicate handle");
     *revaptr = 1;                                 /* Indicate error */
     return;
   }
   if ((stream = fdopen (filenum, "w")) == NULL) { /* Build stream from handle */
-    errorPrint ("SCOTCHFGRAPHORDERSAVE: cannot open output stream");
+    errorPrint (STRINGIFY (SCOTCH_NAME_PUBLICFU (GRAPHORDERSAVE)) ": cannot open output stream");
     close      (filenum);
     *revaptr = 1;
     return;
@@ -140,12 +141,12 @@ int * const                   revaptr),         \
 **
 */
 
-FORTRAN (                                             \
-SCOTCHFGRAPHORDERSAVEMAP, scotchfgraphordersavemap, ( \
-const SCOTCH_Graph * const    grafptr,                \
-const SCOTCH_Ordering * const ordeptr,                \
-int * const                   fileptr,                \
-int * const                   revaptr),               \
+SCOTCH_FORTRAN (                        \
+GRAPHORDERSAVEMAP, graphordersavemap, ( \
+const SCOTCH_Graph * const    grafptr,  \
+const SCOTCH_Ordering * const ordeptr,  \
+int * const                   fileptr,  \
+int * const                   revaptr), \
 (grafptr, ordeptr, fileptr, revaptr))
 {
   FILE *              stream;                     /* Stream to build from handle */
@@ -153,13 +154,13 @@ int * const                   revaptr),               \
   int                 o;
 
   if ((filenum = dup (*fileptr)) < 0) {           /* If cannot duplicate file descriptor */
-    errorPrint ("SCOTCHFGRAPHORDERSAVEMAP: cannot duplicate handle");
+    errorPrint (STRINGIFY (SCOTCH_NAME_PUBLICFU (GRAPHORDERSAVEMAP)) ": cannot duplicate handle");
 
     *revaptr = 1;                                 /* Indicate error */
     return;
   }
   if ((stream = fdopen (filenum, "w")) == NULL) { /* Build stream from handle */
-    errorPrint ("SCOTCHFGRAPHORDERSAVEMAP: cannot open output stream");
+    errorPrint (STRINGIFY (SCOTCH_NAME_PUBLICFU (GRAPHORDERSAVEMAP)) ": cannot open output stream");
     close      (filenum);
     *revaptr = 1;
     return;
@@ -176,12 +177,12 @@ int * const                   revaptr),               \
 **
 */
 
-FORTRAN (                                               \
-SCOTCHFGRAPHORDERSAVETREE, scotchfgraphordersavetree, ( \
-const SCOTCH_Graph * const    grafptr,                  \
-const SCOTCH_Ordering * const ordeptr,                  \
-int * const                   fileptr,                  \
-int * const                   revaptr),                 \
+SCOTCH_FORTRAN (                          \
+GRAPHORDERSAVETREE, graphordersavetree, ( \
+const SCOTCH_Graph * const    grafptr,    \
+const SCOTCH_Ordering * const ordeptr,    \
+int * const                   fileptr,    \
+int * const                   revaptr),   \
 (grafptr, ordeptr, fileptr, revaptr))
 {
   FILE *              stream;                     /* Stream to build from handle */
@@ -189,13 +190,13 @@ int * const                   revaptr),                 \
   int                 o;
 
   if ((filenum = dup (*fileptr)) < 0) {           /* If cannot duplicate file descriptor */
-    errorPrint ("SCOTCHFGRAPHORDERSAVETREE: cannot duplicate handle");
+    errorPrint (STRINGIFY (SCOTCH_NAME_PUBLICFU (GRAPHORDERSAVETREE)) ": cannot duplicate handle");
 
     *revaptr = 1;                                 /* Indicate error */
     return;
   }
   if ((stream = fdopen (filenum, "w")) == NULL) { /* Build stream from handle */
-    errorPrint ("SCOTCHFGRAPHORDERSAVETREE: cannot open output stream");
+    errorPrint (STRINGIFY (SCOTCH_NAME_PUBLICFU (GRAPHORDERSAVETREE)) ": cannot open output stream");
     close      (filenum);
     *revaptr = 1;
     return;
@@ -212,85 +213,85 @@ int * const                   revaptr),                 \
 **
 */
 
-FORTRAN (                                             \
-SCOTCHFGRAPHORDERCOMPUTE, scotchfgraphordercompute, ( \
-SCOTCH_Graph * const        grafptr,                  \
-SCOTCH_Ordering * const     ordeptr,                  \
-SCOTCH_Strat * const        stratptr,                 \
-int * const                 revaptr),                 \
-(grafptr, ordeptr, stratptr, revaptr))
+SCOTCH_FORTRAN (                        \
+GRAPHORDERCOMPUTE, graphordercompute, ( \
+SCOTCH_Graph * const        grafptr,    \
+SCOTCH_Ordering * const     ordeptr,    \
+SCOTCH_Strat * const        straptr,    \
+int * const                 revaptr),   \
+(grafptr, ordeptr, straptr, revaptr))
 {
-  *revaptr = SCOTCH_graphOrderCompute (grafptr, ordeptr, stratptr);
+  *revaptr = SCOTCH_graphOrderCompute (grafptr, ordeptr, straptr);
 }
 
 /*
 **
 */
 
-FORTRAN (                                                     \
-SCOTCHFGRAPHORDERCOMPUTELIST, scotchfgraphordercomputelist, ( \
-SCOTCH_Graph * const        grafptr,                          \
-SCOTCH_Ordering * const     ordeptr,                          \
-const SCOTCH_Num *          listptr,                          \
-const SCOTCH_Num * const    listtab,                          \
-SCOTCH_Strat * const        stratptr,                         \
-int * const                 revaptr),                         \
-(grafptr, ordeptr, listptr, listtab, stratptr, revaptr))
-{
-  *revaptr = SCOTCH_graphOrderComputeList (grafptr, ordeptr, *listptr, listtab, stratptr);
-}
-
-/*
-**
-*/
-
-FORTRAN (                                       \
-SCOTCHFGRAPHORDER, scotchfgraphorder, (         \
+SCOTCH_FORTRAN (                                \
+GRAPHORDERCOMPUTELIST, graphordercomputelist, ( \
 SCOTCH_Graph * const        grafptr,            \
-SCOTCH_Strat * const        stratptr,           \
-SCOTCH_Num * const          permtab,            \
-SCOTCH_Num * const          peritab,            \
-SCOTCH_Num * const          cblkptr,            \
-SCOTCH_Num * const          rangtab,            \
-SCOTCH_Num * const          treetab,            \
+SCOTCH_Ordering * const     ordeptr,            \
+const SCOTCH_Num *          listptr,            \
+const SCOTCH_Num * const    listtab,            \
+SCOTCH_Strat * const        straptr,            \
 int * const                 revaptr),           \
-(grafptr, stratptr, permtab, peritab,           \
+(grafptr, ordeptr, listptr, listtab, straptr, revaptr))
+{
+  *revaptr = SCOTCH_graphOrderComputeList (grafptr, ordeptr, *listptr, listtab, straptr);
+}
+
+/*
+**
+*/
+
+SCOTCH_FORTRAN (                      \
+GRAPHORDER, graphorder, (             \
+SCOTCH_Graph * const        grafptr,  \
+SCOTCH_Strat * const        straptr,  \
+SCOTCH_Num * const          permtab,  \
+SCOTCH_Num * const          peritab,  \
+SCOTCH_Num * const          cblkptr,  \
+SCOTCH_Num * const          rangtab,  \
+SCOTCH_Num * const          treetab,  \
+int * const                 revaptr), \
+(grafptr, straptr, permtab, peritab,  \
  cblkptr, rangtab, treetab, revaptr))
 {
-  *revaptr = SCOTCH_graphOrder (grafptr, stratptr, permtab, peritab, cblkptr, rangtab, treetab);
+  *revaptr = SCOTCH_graphOrder (grafptr, straptr, permtab, peritab, cblkptr, rangtab, treetab);
 }
 
 /*
 **
 */
 
-FORTRAN (                                       \
-SCOTCHFGRAPHORDERLIST, scotchfgraphorderlist, ( \
-SCOTCH_Graph * const        grafptr,            \
-const SCOTCH_Num * const    listptr,            \
-const SCOTCH_Num * const    listtab,            \
-SCOTCH_Strat * const        stratptr,           \
-SCOTCH_Num * const          permtab,            \
-SCOTCH_Num * const          peritab,            \
-SCOTCH_Num * const          cblkptr,            \
-SCOTCH_Num * const          rangtab,            \
-SCOTCH_Num * const          treetab,            \
-int * const                 revaptr),           \
-(grafptr, listptr, listtab, stratptr,           \
+SCOTCH_FORTRAN (                      \
+GRAPHORDERLIST, graphorderlist, (     \
+SCOTCH_Graph * const        grafptr,  \
+const SCOTCH_Num *          listptr,  \
+const SCOTCH_Num * const    listtab,  \
+SCOTCH_Strat * const        straptr,  \
+SCOTCH_Num * const          permtab,  \
+SCOTCH_Num * const          peritab,  \
+SCOTCH_Num * const          cblkptr,  \
+SCOTCH_Num * const          rangtab,  \
+SCOTCH_Num * const          treetab,  \
+int * const                 revaptr), \
+(grafptr, listptr, listtab, straptr,  \
  permtab, peritab, cblkptr, rangtab, treetab, revaptr))
 {
-  *revaptr = SCOTCH_graphOrderList (grafptr, *listptr, listtab, stratptr, permtab, peritab, cblkptr, rangtab, treetab);
+  *revaptr = SCOTCH_graphOrderList (grafptr, *listptr, listtab, straptr, permtab, peritab, cblkptr, rangtab, treetab);
 }
 
 /*
 **
 */
 
-FORTRAN (                                         \
-SCOTCHFGRAPHORDERCHECK, scotchfgraphordercheck, ( \
-const SCOTCH_Graph * const    grafptr,            \
-const SCOTCH_Ordering * const ordeptr,            \
-int * const                   revaptr),           \
+SCOTCH_FORTRAN (                        \
+GRAPHORDERCHECK, graphordercheck, (     \
+const SCOTCH_Graph * const    grafptr,  \
+const SCOTCH_Ordering * const ordeptr,  \
+int * const                   revaptr), \
 (grafptr, ordeptr, revaptr))
 {
   *revaptr = SCOTCH_graphOrderCheck (grafptr, ordeptr);
@@ -300,24 +301,25 @@ int * const                   revaptr),           \
 **
 */
 
-FORTRAN (                                         \
-SCOTCHFSTRATGRAPHORDER, scotchfstratgraphorder, ( \
-SCOTCH_Strat * const        stratptr,             \
-const char * const          string,               \
-int * const                 revaptr,              \
-const int                   strnbr),              \
-(stratptr, string, revaptr, strnbr))
+SCOTCH_FORTRAN (                     \
+STRATGRAPHORDER, stratgraphorder, (  \
+SCOTCH_Strat * const        straptr, \
+const char * const          string,  \
+int * const                 revaptr, \
+const int                   strnbr), \
+(straptr, string, revaptr, strnbr))
 {
   char * restrict     strtab;                     /* Pointer to null-terminated string */
 
   if ((strtab = (char *) memAlloc (strnbr + 1)) == NULL) { /* Allocate temporary space */
-    errorPrint ("SCOTCHFSTRATGRAPHORDER: out of memory (1)");
+    errorPrint (STRINGIFY (SCOTCH_NAME_PUBLICFU (STRATGRAPHORDER)) ": out of memory");
     *revaptr = 1;
+    return;
   }
   memCpy (strtab, string, strnbr);                /* Copy string contents */
   strtab[strnbr] = '\0';                          /* Terminate string     */
 
-  *revaptr = SCOTCH_stratGraphOrder (stratptr, strtab); /* Call original routine */
+  *revaptr = SCOTCH_stratGraphOrder (straptr, strtab); /* Call original routine */
 
   memFree (strtab);                               /* Prevent compiler warnings */
 }
@@ -326,13 +328,14 @@ const int                   strnbr),              \
 **
 */
 
-FORTRAN (                                                   \
-SCOTCHFSTRATGRAPHORDERBUILD, scotchfstratgraphorderbuild, ( \
-SCOTCH_Strat * const        stratptr,                       \
-const SCOTCH_Num * const    flagval,                        \
-const double * const        balrat,                         \
-int * const                 revaptr),                       \
-(stratptr, flagval, balrat, revaptr))
+SCOTCH_FORTRAN (                              \
+STRATGRAPHORDERBUILD, stratgraphorderbuild, ( \
+SCOTCH_Strat * const        straptr,          \
+const SCOTCH_Num * const    flagval,          \
+const SCOTCH_Num * const    levlnbr,          \
+const double * const        kbalval,          \
+int * const                 revaptr),         \
+(straptr, flagval, levlnbr, kbalval, revaptr))
 {
-  *revaptr = SCOTCH_stratGraphOrderBuild (stratptr, *flagval, *balrat);
+  *revaptr = SCOTCH_stratGraphOrderBuild (straptr, *levlnbr, *flagval, *kbalval);
 }
