@@ -1,4 +1,4 @@
-/* Copyright 2004,2007 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007,2011-2014 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -34,6 +34,7 @@
 /**   NAME       : vgraph_separate_st.c                    **/
 /**                                                        **/
 /**   AUTHOR     : Francois PELLEGRINI                     **/
+/**                Sebastien FOURESTIER (v6.0)             **/
 /**                                                        **/
 /**   FUNCTION   : This module contains the global         **/
 /**                separation strategy and method tables.  **/
@@ -48,6 +49,8 @@
 /**                                 to   : 02 oct 2007     **/
 /**                # Version 5.1  : from : 30 oct 2007     **/
 /**                                 to   : 01 jul 2008     **/
+/**                # Version 6.0  : from : 09 mar 2011     **/
+/**                                 to     01 may 2014     **/
 /**                                                        **/
 /************************************************************/
 
@@ -62,9 +65,9 @@
 #include "gain.h"
 #include "parser.h"
 #include "graph.h"
-#include "graph_coarsen.h"
 #include "arch.h"
 #include "mapping.h"
+#include "graph_coarsen.h"
 #include "bgraph.h"
 #include "bgraph_bipart_st.h"
 #include "vgraph.h"
@@ -178,14 +181,14 @@ static StratParamTab        vgraphseparatestparatab[] = { /* Graph separation me
                               { VGRAPHSEPASTMETHML,  STRATPARAMCASE,   "type",
                                 (byte *) &vgraphseparatedefaultml.param,
                                 (byte *) &vgraphseparatedefaultml.param.coartype,
-                                (void *) "hscd" },
+                                (void *) "hs" },
                               { VGRAPHSEPASTMETHML,  STRATPARAMINT,    "vert",
                                 (byte *) &vgraphseparatedefaultml.param,
                                 (byte *) &vgraphseparatedefaultml.param.coarnbr,
                                 NULL },
                               { VGRAPHSEPASTMETHML,  STRATPARAMDOUBLE, "rat",
                                 (byte *) &vgraphseparatedefaultml.param,
-                                (byte *) &vgraphseparatedefaultml.param.coarrat,
+                                (byte *) &vgraphseparatedefaultml.param.coarval,
                                 NULL },
                               { VGRAPHSEPASTMETHNBR, STRATPARAMINT,    NULL,
                                 NULL, NULL, NULL } };
@@ -203,16 +206,6 @@ static StratParamTab        vgraphseparatestcondtab[] = { /* Graph condition par
                                 (byte *) &vgraphdummy,
                                 (byte *) &vgraphdummy.s.velosum,
                                 NULL },
-#ifdef SCOTCH_PTSCOTCH
-                              { STRATNODECOND,       STRATPARAMINT,    "proc",
-                                (byte *) &vgraphdummy,
-                                (byte *) &vgraphdummy.s.procglbnbr,
-                                NULL },
-                              { STRATNODECOND,       STRATPARAMINT,    "rank",
-                                (byte *) &vgraphdummy,
-                                (byte *) &vgraphdummy.s.proclocnum,
-                                NULL },
-#endif /* SCOTCH_PTSCOTCH */
                               { STRATNODECOND,       STRATPARAMINT,    "vert",
                                 (byte *) &vgraphdummy,
                                 (byte *) &vgraphdummy.s.vertnbr,
@@ -246,6 +239,7 @@ const Strat * restrict const  strat)              /*+ Separation strategy +*/
 {
   StratTest           val;
   VgraphStore         savetab[2];                 /* Results of the two strategies */
+  Gnum                compload2;                  /* Saved separator load          */
   int                 o;
 
 #ifdef SCOTCH_DEBUG_VGRAPH2
@@ -317,8 +311,9 @@ const Strat * restrict const  strat)              /*+ Separation strategy +*/
       if (vgraphSeparateSt (grafptr, strat->data.select.strat[1]) != 0) /* If second strategy didn't work */
         vgraphStoreUpdt (grafptr, &savetab[1]);   /* Restore initial bipartition as its result            */
 
-      if ( (savetab[0].fronnbr <  grafptr->fronnbr) || /* If first strategy is better */
-          ((savetab[0].fronnbr == grafptr->fronnbr) &&
+      compload2 = grafptr->s.velosum - savetab[0].compload[0] - savetab[0].compload[1]; /* Compute saved separator load */
+      if ( (compload2 <  grafptr->compload[2]) || /* If first strategy is better */
+          ((compload2 == grafptr->compload[2]) &&
            (abs (savetab[0].comploaddlt) < abs (grafptr->comploaddlt))))
         vgraphStoreUpdt (grafptr, &savetab[0]);   /* Restore its result */
 
