@@ -1,4 +1,4 @@
-/* Copyright 2007,2010,2012,2015 IPB, Universite de Bordeaux, INRIA & CNRS
+/* Copyright 2007,2010,2012,2015,2019 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -44,7 +44,7 @@
 /**                # Version 5.1  : from : 30 jun 2010     **/
 /**                                 to     30 jun 2010     **/
 /**                # Version 6.0  : from : 13 sep 2012     **/
-/**                                 to     27 apr 2015     **/
+/**                                 to     18 may 2019     **/
 /**                                                        **/
 /************************************************************/
 
@@ -67,21 +67,45 @@
 /*                                    */
 /**************************************/
 
-/*
-**
-*/
+FORTRAN (                                               \
+SCOTCH_PARMETIS_V3_NODEND, scotch_parmetis_v3_nodend, ( \
+const SCOTCH_Num * const    vtxdist,                    \
+SCOTCH_Num * const          xadj,                       \
+SCOTCH_Num * const          adjncy,                     \
+const SCOTCH_Num * const    numflag,                    \
+const SCOTCH_Num * const    options,                    \
+SCOTCH_Num * const          order,                      \
+SCOTCH_Num * const          sizes,                      \
+MPI_Comm * const            commptr,                    \
+int * const                 revaptr),                   \
+(vtxdist, xadj, adjncy, numflag, options, order, sizes, commptr, revaptr))
+{
+  *revaptr = SCOTCH_ParMETIS_V3_NodeND (vtxdist, xadj, adjncy, numflag, options, order, sizes, commptr);
+}
 
-FORTRAN (                                                         \
-METISNAMEU(PARMETIS_V3_NODEND), METISNAMEL(parmetis_v3_nodend), ( \
-const SCOTCH_Num * const    vtxdist,                              \
-SCOTCH_Num * const          xadj,                                 \
-SCOTCH_Num * const          adjncy,                               \
-const SCOTCH_Num * const    numflag,                              \
-const SCOTCH_Num * const    options,                              \
-SCOTCH_Num * const          order,                                \
-SCOTCH_Num * const          sizes,                                \
-MPI_Comm * const            commptr),                             \
+/*******************/
+/*                 */
+/* MeTiS v3 stubs. */
+/*                 */
+/*******************/
+
+#if (SCOTCH_PARMETIS_VERSION == 3)
+#ifndef SCOTCH_METIS_PREFIX                       /* With "SCOTCH_" prefix, names already defined */
+
+FORTRAN (                                                           \
+METISNAMEU (PARMETIS_V3_NODEND), METISNAMEL (parmetis_v3_nodend), ( \
+const SCOTCH_Num * const    vtxdist,                                \
+SCOTCH_Num * const          xadj,                                   \
+SCOTCH_Num * const          adjncy,                                 \
+const SCOTCH_Num * const    numflag,                                \
+const SCOTCH_Num * const    options,                                \
+SCOTCH_Num * const          order,                                  \
+SCOTCH_Num * const          sizes,                                  \
+MPI_Comm * const            commptr),                               \
 (vtxdist, xadj, adjncy, numflag, options, order, sizes, commptr))
 {
-  METISNAMEU(ParMETIS_V3_NodeND) (vtxdist, xadj, adjncy, numflag, options, order, sizes, commptr);
+  METISNAMEU (ParMETIS_V3_NodeND) (vtxdist, xadj, adjncy, numflag, options, order, sizes, commptr);
 }
+
+#endif /* SCOTCH_METIS_PREFIX */
+#endif /* (SCOTCH_PARMETIS_VERSION == 3) */
