@@ -1,4 +1,4 @@
-/* Copyright 2004,2007,2008 ENSEIRB, INRIA & CNRS
+/* Copyright 2004,2007,2008,2014 IPB, Universite de Bordeaux, INRIA & CNRS
 **
 ** This file is part of the Scotch software package for static mapping,
 ** graph partitioning and sparse matrix ordering.
@@ -47,6 +47,8 @@
 /**                                 to   : 03 jun 1997     **/
 /**                # Version 3.3  : from : 06 oct 1998     **/
 /**                                 to   : 06 oct 1998     **/
+/**                # Version 6.0  : from : 12 nov 2014     **/
+/**                                 to   : 12 nov 2014     **/
 /**                                                        **/
 /************************************************************/
 
@@ -59,6 +61,6 @@
 #define C_FILENBR                   1             /* Number of files in list                */
 #define C_FILEARGNBR                1             /* Number of files which can be arguments */
 
-#define C_filenamesrcout            C_fileTab[0].name /* Source graph output file name */
+#define C_filenamesrcout            fileBlockName (C_fileTab, 0) /* Source graph output file name */
 
-#define C_filepntrsrcout            C_fileTab[0].pntr /* Source graph output file */
+#define C_filepntrsrcout            fileBlockFile (C_fileTab, 0) /* Source graph output file */
